from io import BytesIO
import time
import zipfile
import bambulabs_api as bl
import os

IP = '192.168.1.200'
SERIAL = 'AC12309BH109'
ACCESS_CODE = '12347890'

# ============================================================
# This example is designed to work with 3mf files generated by
# OrcaSlicer
# ============================================================
INPUT_FILE_PATH = 'bambulab_api_example.3mf'
# ============================================================

env = os.getenv("env", "debug")


def gcode_files_in_3mf(
        zipfile_path: str) -> list[str]:
    """
    Get the gcodefiles in the 3mf.

    Args:
        zipfile_path (str): location of the text file.

    Returns:
        list[str]: first gcode file, or None if not found
    """
    zf = zipfile.ZipFile(zipfile_path)

    nl = zf.namelist()
    print(nl)
    return [n for n in nl if n.endswith(".gcode") and n.startswith("Metadata/plate_")]  # noqa: E501


if __name__ == '__main__':
    print('Starting bambulabs_api example')
    print('Connecting to Bambulabs 3D printer')
    print(f'IP: {IP}')
    print(f'Serial: {SERIAL}')
    print(f'Access Code: {ACCESS_CODE}')

    # Create a new instance of the API
    printer = bl.Printer(IP, ACCESS_CODE, SERIAL)

    # Connect to the Bambulabs 3D printer
    printer.connect()

    time.sleep(5)

    gcode_location = next(
        (i for i in gcode_files_in_3mf(INPUT_FILE_PATH)), None)

    if gcode_location:
        with open(INPUT_FILE_PATH, "rb") as file:
            io_file = BytesIO(file.read())
        result = printer.upload_file(io_file, INPUT_FILE_PATH)
        if "226" not in result:
            print("Error Uploading File to Printer")

        else:
            print("Done Uploading/Sending Start Print Command")
            printer.start_print(INPUT_FILE_PATH, 1)
            print("Start Print Command Sent")
    else:
        print("No gcode file found in 3mf")
